# Isolating application components

If you are interested in components from the application layers of your image, but not interested in components from the underlying platform layers, you can exclude components from platform layers from the results.

For example, if you build your application on ubuntu:latest (your Dockerfile starts with FROM ubuntu:latest), you can exclude components from the Ubuntu layer(s) so that the components generated by [company_name] [solution_name] using Docker Inspector and the [blackduck_signature_scanner_name] contain only components from your application layers.

First, find the layer ID of the platform's top layer. To do this task:

Run the `docker inspect` command on the base image; in our example this is *ubuntu:latest*.
Find the last element in the *RootFS.Layers* array. This is the platform top layer ID. In the following example, the platform top layer ID is
*sha256:b079b3fa8d1b4b30a71a6e81763ed3da1327abaf0680ed3ed9f00ad1d5de5e7c*.
Set the value of the Docker Inspector property docker.platform.top.layer.id to the platform top layer ID. For example:
````
./detect9.sh ... --detect.docker.image={your application image} --detect.docker.platform.top.layer.id=sha256:b079b3fa8d1b4b30a71a6e81763ed3da1327abaf0680ed3ed9f00ad1d5de5e7c
````
In this mode, there may be some loss in match accuracy from the [blackduck_signature_scanner_name] because, in this scenario, the [blackduck_signature_scanner_name] may be deprived of some contextual information, such as the operating system files that enable it to determine the Linux distribution, and that that may negatively affect its ability to accurately identify components.

